@@ -3,23 +3,17 @@ OC.L10N.register(
     {
     "Details" : "Detalles",
     "All contacts" : "Tolos contautos",
-    "Loading circle …" : "Cargando'l círculu…",
     "Loading contacts …" : "Cargando los contautos…",
     "There are no contacts yet" : "Nun hai nengún contautu",
     "There are no contacts in this group" : "Nun hai nengún contautu nesti grupu",
     "Add contacts" : "Amestar contautos",
     "Loading …" : "Cargando…",
     "Add member" : "Amestar un miembru",
-    "Delete circle" : "Desaniciar el círculu",
     "Contacts settings" : "Configuración de Contautos",
     "General settings" : "Configuración xeneral",
     "Export" : "Esportar",
     "Contact groups" : "Grupos de contautos",
-    "Circles" : "Círculos",
-    "Create a new circle" : "Crear un círculu",
     "This group already exists" : "Esti grupu yá esiste",
-    "This circle already exists" : "Esti círculu yá esiste",
-    "An error happened during the creation of the circle" : "Prodúxose un error demientres la creación del círculu",
     "Download" : "Baxar",
     "Delete" : "Desaniciar",
     "Copied" : "Copióse",
@@ -35,9 +29,9 @@ OC.L10N.register(
     "Display name" : "Nome visible",
     "An error happened during the config change" : "Prodúxose un error demientres el cambéu de la configuración",
     "Save" : "Guardar",
+    "Failed to save password. Please try again later." : "Nun se pue guardar la contraseña. Volvi tentalo dempués.",
     "Description" : "Descripción",
-    "There is no description for this circle" : "Nun hai nenguna descripción pa esti círculu",
-    "Enter a description for the circle" : "Introduz una descripción pal círculu",
+    "Settings" : "Configuración",
     "More fields" : "Más campos",
     "Company" : "Compaña",
     "Edit" : "Editar",
@@ -46,7 +40,6 @@ OC.L10N.register(
     "An error occurred while trying to move the contact" : "Prodúxose un error al tentar de mover el contautu",
     "An error occurred while trying to copy the contact" : "Prodúxose un error al tentar de copiar el contautu",
     "Unable to update contact" : "Nun ye posible anovar el contautu",
-    "Create circle" : "Crear el círculu",
     "Loading members list …" : "Cargando la llista de miembros…",
     "New contact" : "Contautu nuevu",
     "Unable to create the contact." : "Nun ye posible crear el contautu.",
@@ -55,7 +48,6 @@ OC.L10N.register(
     "Not grouped" : "Ensin grupu",
     "Members need to accept invitation" : "Los miembros precisen aceptar la invitación",
     "Members can also invite" : "Los miembros tamién puen convidar",
-    "Prevent circle from being a member of another circle" : "Evitar que'l círculu seya miembru d'otru círculu",
     "Prefix" : "Prefixu",
     "Suffix" : "Sufixu",
     "Nickname" : "Nomatu",
@@ -70,7 +62,6 @@ OC.L10N.register(
     "Fax" : "Fax",
     "Pager" : "Buscapersones",
     "Father" : "Pá",
-    "Agent" : "Axente",
-    "Unable to create circle {circleName}" : "Nun ye posible crear el círculu «{circleName}»"
+    "Agent" : "Axente"
 },
 "nplurals=2; plural=(n != 1);");
