@@ -12,11 +12,13 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Save" : "Saxla",
     "Description" : "Açıqlanma",
+    "Settings" : "Settings",
     "Cancel" : "Dayandır",
     "Invalid image" : "Yalnış şəkil",
     "Name" : "Ad",
     "Title" : "Başlıq",
     "Pending" : "Gözləmə",
+    "None" : "Heç bir",
     "Close" : "Bağla",
     "Import" : "Əlavə et",
     "Not grouped" : "Qruplaşdırılmayıb",
@@ -26,13 +28,23 @@ OC.L10N.register(
     "Admin" : "İnzibatçı",
     "Owner" : "Owner",
     "Users" : "İstifadəçilər",
+    "Prefix" : "Prefiks",
+    "Suffix" : "Suffiks",
+    "Nickname" : "Ləqəb",
     "Notes" : "Qeydlər",
+    "Website" : "Veb sayt",
     "Location" : "Yerləşdiyiniz ünvan",
     "Home" : "Ev",
     "Work" : "İş",
     "Other" : "Digər",
     "Address" : "Ünvan",
+    "City" : "Şəhər",
+    "Country" : "Ölkə",
     "Birthday" : "Ad günü",
-    "None" : "Heç bir"
+    "Anniversary" : "Yubiley",
+    "Phone" : "Telefon",
+    "Mobile" : "Mobil",
+    "Fax" : "Faks",
+    "Pager" : "Peycer"
 },
 "nplurals=2; plural=(n != 1);");
