@@ -5,11 +5,8 @@ OC.L10N.register(
     "All contacts" : "Todos los contactos",
     "Contacts" : "Contactos",
     "Loading contacts …" : "Cargando contactos ...",
-    "Delete circle" : "Borrar círculo",
     "General settings" : "Configuraciones generales",
     "Send email" : "Enviar correo electrónico",
-    "Circles" : "Círculos",
-    "Create a new circle" : "Crear un nuevo círculo",
     "Download" : "Descargar",
     "Rename" : "Renombrar",
     "Delete" : "Borrar",
@@ -23,6 +20,7 @@ OC.L10N.register(
     "Password protection" : "Protección con contraseña",
     "Save" : "Guardar",
     "Description" : "Descripción",
+    "Settings" : "Settings",
     "Cancel" : "Cancelar",
     "Invalid image" : "Imagen inválida",
     "Name" : "Nombre",
@@ -30,13 +28,12 @@ OC.L10N.register(
     "Address book" : "Libreta de direcciones",
     "Search contacts …" : "Buscar contactos ...",
     "No results" : "No hay resultados",
-    "Personal circle" : "Círculo personal",
     "Pending" : "Pendiente",
+    "None" : "Ninguno",
     "New contact" : "Nuevo contacto",
     "Close" : "Cerrar",
     "Import" : "Importar",
     "Not grouped" : "No agrupado",
-    "Circle" : "Círculo",
     "User" : "Ususario",
     "Group" : "Grupo",
     "Email" : "Correo electrónico",
@@ -94,7 +91,6 @@ OC.L10N.register(
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
-    "None" : "Ninguno",
     "Unknown" : "Desconocido"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
