@@ -22,6 +22,7 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Save" : "Salvesta",
     "Description" : "Kirjeldus",
+    "Settings" : "Settings",
     "Cancel" : "Loobu",
     "Delete picture" : "Kustuta pilt",
     "Invalid image" : "Vigane pilt",
@@ -30,13 +31,12 @@ OC.L10N.register(
     "Address book" : "Aadressiraamat",
     "Search contacts …" : "Otsi kontakte",
     "No results" : "Vasteid ei leitud",
-    "Personal circle" : "Isiklik ring",
     "Pending" : "Ootel",
+    "None" : "Pole",
     "New contact" : "Uus kontakt",
     "Close" : "Sulge",
     "Import" : "Impordi",
     "Not grouped" : "Pole grupeeritud",
-    "Circle" : "Ring",
     "User" : "Kasutaja",
     "Group" : "Grupp",
     "Email" : "E-post",
@@ -94,7 +94,6 @@ OC.L10N.register(
     "Gender" : "Sugu",
     "Female" : "Naine",
     "Male" : "Mees",
-    "None" : "Pole",
     "Unknown" : "Teadmata"
 },
 "nplurals=2; plural=(n != 1);");
