@@ -9,9 +9,6 @@ OC.L10N.register(
     "Copy to full name" : "フルネームをコピー",
     "Omit year" : "年を省略する",
     "Allow updating avatars from social media" : "ソーシャルメディアからのアバターの更新を許可する",
-    "Please select a circle" : "サークルを選択",
-    "Loading circle …" : "サークルを読み込み中...",
-    "Your request to join this circle is pending approval" : "このサークルへの参加リクエストは承認待ちです",
     "You are not a member of {circle}" : "あなたはサークル{circle}のメンバーではありません",
     "There was an error fetching the member list" : "メンバーリストの取得中にエラーが発生しました",
     "Loading contacts …" : "連絡先を読み込み中...",
@@ -22,8 +19,6 @@ OC.L10N.register(
     "Add contacts" : "連絡先を追加",
     "Loading …" : "読み込み中…",
     "Add member" : "メンバーの追加",
-    "Leave circle" : "サークルを退会する",
-    "Delete circle" : "サークルを削除",
     "Contacts settings" : "連絡先の設定",
     "General settings" : "一般設定",
     "Update avatars from social media" : "SNSでアバターをアップデート",
@@ -35,15 +30,9 @@ OC.L10N.register(
     "Contact groups" : "連絡先グループ",
     "Create a new contact group" : "新規連絡先グループを作成",
     "Contact group name" : "連絡先グループ名",
-    "Circles" : "サークル",
-    "Create a new circle" : "新しいサークルを作成する",
     "Show all groups" : "すべてのグループを表示",
     "Collapse groups" : "グループを折りたたむ",
-    "Show all circles" : "すべてのサークルを表示",
-    "Collapse circles" : "サークルを折りたたむ",
     "This group already exists" : "このグループはすでに存在しています",
-    "This circle already exists" : "このサークルはすでに存在します",
-    "An error happened during the creation of the circle" : "サークルの作成中にエラーが発生しました",
     "{addressbookname} (Disabled)" : "{addressbookname} (無効)",
     "Download" : "ダウンロード",
     "Show" : "表示",
@@ -85,24 +74,20 @@ OC.L10N.register(
     "Oversees" : "統括",
     "An error happened during the config change" : "構成の変更中にエラーが発生しました",
     "Password protection" : "パスワード保護",
-    "Enforce password protection on files shared to this circle" : "このサークルへのファイル共有にはパスワードを強制します",
-    "Use a unique password for all shares to this circle" : "このサークルへのすべての共有に一意のパスワードを使用します",
     "Unique password …" : "固有パスワード...",
     "Save" : "保存",
     "Change unique password" : "固有パスワードを変更",
     "Failed to save password. Please try again later." : "パスワードを保存できませんでした。後でもう一度やり直してください",
-    "Circle name" : "サークル名",
-    "Circle owned by {owner}" : "{owner}が所有しているサークル",
     "Request to join" : "参加リクエスト",
     "Description" : "詳細",
-    "There is no description for this circle" : "このサークルについての説明はありません",
-    "Enter a description for the circle" : "サークルについて説明を入力してください",
+    "Add members" : "メンバーの追加",
+    "Settings" : "Settings",
     "An error happened during description sync" : "説明の同期中にエラーが発生しました",
     "An error happened during name sync" : "名前の同期中にエラーが発生しました",
+    "Cancel" : "キャンセル",
     "Add more info" : "さらに情報を追加",
     "More fields" : "その他のフィールド",
     "Crop contact photo" : "写真を切り抜き",
-    "Cancel" : "キャンセル",
     "Upload a new picture" : "新しい写真をアップロードする",
     "Choose from Files" : "ファイルから選択",
     "Get from " : "次から入手:",
@@ -150,22 +135,12 @@ OC.L10N.register(
     "No results" : "該当なし",
     "Add to group" : "グループに追加",
     "Add {type}" : "{type}を追加",
-    "New circle name" : "新しいサークル名",
-    "Personal circle" : "パーソナルサークル",
-    "This circle will only be visible to you. Other members will not be able to see or use it." : "このサークルはあなただけに表示されます。他のメンバーはそれを見たり使用したりすることはできません。",
-    "Local circle" : "ローカルサークル",
-    "This circle will not be shared with the other instances of the global scale" : "このサークルは、グローバルスケールの他のインスタンスと共有されません",
-    "Create circle" : "サークルを作成",
     "Loading members list …" : "メンバーリストを読み込んでいます…",
-    "The list of members is only visible to members of this circle" : "メンバーのリストは、このサークルのメンバーにのみ表示されます",
     "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
-    "Add members" : "メンバーの追加",
-    "Show circle details" : "サークル詳細を表示",
     "Add to {circle}" : "{circle} に追加",
     "Unable to get the recommendations list" : "おすすめリストを取得できません",
     "Unable to get the results" : "結果を取得できません",
     "Some members could not be added" : "一部のメンバーを追加できませんでした",
-    "There was an issue adding members to the circle" : "サークルにメンバーを追加する際に問題が発生しました",
     "Accept membership request" : "メンバーシップリクエストを受け入れる",
     "Reject membership request" : "メンバーシップリクエストを拒否",
     "Manage level" : "レベルを管理",
@@ -182,7 +157,7 @@ OC.L10N.register(
     "Select type" : "タイプを選択",
     "Select Date" : "日付を選択",
     "Add contact in group" : "グループに連絡先を追加",
-    "none" : "なし",
+    "None" : "なし",
     "Select option" : "オプションを選択",
     "Add property of this type" : "このタイプのプロパティーを追加",
     "New contact" : "新しい連絡先",
@@ -197,21 +172,13 @@ OC.L10N.register(
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n 連絡先のインポートが完了しました"],
     "Import" : "インポート",
     "Could not copy" : "コピーできませんでした",
-    "Join circle" : "サークルに参加",
     "You are about to leave {circle}.\nAre you sure?" : "{circle}を離れようとしています。\nよろしいですか？",
-    "Please confirm circle leave" : "サークルから退会しますか",
-    "Could not leave the circle {displayName}" : "サークル{displayName}を退会できませんでした",
-    "Unable to join the circle" : "サークルに参加できません",
     "You are about to delete {circle}.\nAre you sure?" : "{circle}を削除しようとしています。\nよろしいですか？",
-    "Please confirm circle deletion" : "サークルの削除しますか",
-    "Unable to delete the circle" : "サークルを削除できません",
     "Link copied to the clipboard" : "クリップボードにリンクをコピーしました",
     "Could not copy link to the clipboard." : "クリップボードにコピーできませんでした",
     "Not grouped" : "グループ化されていません",
     "Recently contacted" : "最近連絡した",
     "Organization chart" : "組織図",
-    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "サークルは自分で作成できるグループで、データを共有する先として利用できます。サークルは、Nextcloudインスタンスのアカウントやグループだけでなく、アドレス帳に登録されている連絡先やメールアドレスを入力して外部の人も追加してグループを構成できます。",
-    "Circle" : "サークル",
     "User" : "ユーザー",
     "Group" : "グループ",
     "Email" : "メール",
@@ -227,8 +194,6 @@ OC.L10N.register(
     "Members can also invite" : "メンバーによる招待も可能",
     "Visibility" : "公開レベル",
     "Visible to everyone" : "すべての人に公開",
-    "Circle membership" : "サークルメンバーシップ",
-    "Prevent circle from being a member of another circle" : "サークルが別のサークルのメンバーにならないようにする",
     "Users" : "ユーザー",
     "Email addresses" : "メールアドレス",
     "Detailed name" : "詳細名",
@@ -286,14 +251,10 @@ OC.L10N.register(
     "Gender" : "性別",
     "Female" : "女性",
     "Male" : "男性",
-    "None" : "なし",
     "Unknown" : "不明",
-    "Time zone" : "時間帯",
+    "Time zone" : "タイムゾーン",
     "Spoken languages" : "話せる言語",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed}連絡先の読み込みができませんでした。"],
-    "An error has occurred in circle(s). Check the console for more details." : "サークルでエラーが発生しました。コンソールで詳細を確認してください。",
-    "Unable to create circle {circleName}" : "サークル {circleName} を作成できません",
-    "Unable to delete circle {circleId}" : "サークル{circleId}を削除できません",
     "Unable to delete contact" : "連絡先を削除できません。"
 },
 "nplurals=1; plural=0;");
