@@ -5,11 +5,8 @@ OC.L10N.register(
     "All contacts" : "ყველა კონტაქტი",
     "Contacts" : "კონტაქტები",
     "Loading contacts …" : "კონტაქტების ჩატვირთვა ...",
-    "Delete circle" : "წრის გაუქმება",
     "General settings" : "მთავარი პარამეტრები",
     "Send email" : "ელ-წერილის გაგზავნა",
-    "Circles" : "წრეები",
-    "Create a new circle" : "შექმენით წრე",
     "Download" : "ჩამოტვირთვა",
     "Rename" : "სახელის შეცვლა",
     "Delete" : "გაუქმება",
@@ -23,6 +20,7 @@ OC.L10N.register(
     "Password protection" : "პაროლით თავდაცვა",
     "Save" : "შენახვა",
     "Description" : "აღწერილობა",
+    "Settings" : "Settings",
     "Cancel" : "უარყოფა",
     "Invalid image" : "არასწორი სურათი",
     "Name" : "სახელი",
@@ -30,13 +28,12 @@ OC.L10N.register(
     "Address book" : "მისამართების წიგნი",
     "Search contacts …" : "მოძებნეთ კონტაქტები ...",
     "No results" : "შედეგები არაა",
-    "Personal circle" : "პირადი წრე",
     "Pending" : "მოლოდინში",
+    "None" : "არც ერთი",
     "New contact" : "ახალი კონტაქტი",
     "Close" : "დახურვა",
     "Import" : "იმპორტი",
     "Not grouped" : "არაა დაჯგუფებული",
-    "Circle" : "წრე",
     "User" : "მომხმარებელი",
     "Group" : "ჯგუფი",
     "Email" : "ელ-ფოსტა",
@@ -94,7 +91,6 @@ OC.L10N.register(
     "Gender" : "სქესი",
     "Female" : "მდედორობითი",
     "Male" : "მამრობითი",
-    "None" : "არც ერთი",
     "Unknown" : "ამოუცნობი"
 },
 "nplurals=2; plural=(n!=1);");
