@@ -11,12 +11,14 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Save" : "រក្សាទុក",
     "Description" : "ការ​អធិប្បាយ",
+    "Settings" : "Settings",
     "Cancel" : "បោះបង់",
     "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
     "Name" : "ឈ្មោះ",
     "Title" : "ចំណងជើង",
     "Pending" : "កំពុង​រង់ចាំ",
     "Chart" : "ក្រាប",
+    "None" : "គ្មាន",
     "Close" : "បិទ",
     "Import" : "នាំយកចូល",
     "Not grouped" : "គ្មាន​ក្រុម",
@@ -31,7 +33,6 @@ OC.L10N.register(
     "Work" : "ធ្វើការ",
     "Other" : "ផ្សេងៗ",
     "Address" : "អាសយដ្ឋាន",
-    "Birthday" : "ថ្ងៃ​កំណើត",
-    "None" : "គ្មាន"
+    "Birthday" : "ថ្ងៃ​កំណើត"
 },
 "nplurals=1; plural=0;");
