@@ -8,11 +8,13 @@ OC.L10N.register(
     "can edit" : "﻿ಸಂಪಾದಿಸಬಹುದು",
     "Password protection" : "Password protection",
     "Save" : "﻿ಉಳಿಸಿ",
+    "Settings" : "Settings",
     "Cancel" : "﻿ರದ್ದು",
     "Invalid image" : "ಅಸಾಮರ್ಥ್ಯ ಚಿತ್ರ",
     "Name" : "﻿ಹೆಸರು",
     "Title" : "ಶೀರ್ಷಿಕೆ",
     "Pending" : "﻿ಬಾಕಿ ಇದೆ",
+    "None" : "﻿ಯಾವುದೂ ಇಲ್ಲ",
     "Close" : "ಮುಚ್ಚು",
     "Import" : "ಆಮದು",
     "User" : "User",
@@ -24,7 +26,6 @@ OC.L10N.register(
     "Notes" : "Notes",
     "Home" : "﻿ಮುಖಪುಟ",
     "Other" : "﻿ಇತರೆ",
-    "Address" : "ವಿಳಾಸ",
-    "None" : "﻿ಯಾವುದೂ ಇಲ್ಲ"
+    "Address" : "ವಿಳಾಸ"
 },
 "nplurals=2; plural=(n > 1);");
