@@ -9,9 +9,6 @@ OC.L10N.register(
     "Copy to full name" : "전체 이름으로 복사",
     "Omit year" : "연도 생략",
     "Allow updating avatars from social media" : "소셜 네트워크에서 아바타 업데이트를 허용",
-    "Please select a circle" : "서클을 선택하세요.",
-    "Loading circle …" : "서클 불러오는 중 ...",
-    "Your request to join this circle is pending approval" : "이 서클 등록 요청이 허가를 기다리고 있습니다.",
     "You are not a member of {circle}" : "당신은 {circle}의 회원이 아닙니다.",
     "There was an error fetching the member list" : "회원 목록을 불러오는 중 오류 발생",
     "Loading contacts …" : "연락처 불러오는 중…",
@@ -22,8 +19,6 @@ OC.L10N.register(
     "Add contacts" : "연락처 추가",
     "Loading …" : "불러오는 중 …",
     "Add member" : "회원 추가",
-    "Leave circle" : "서클 떠나기",
-    "Delete circle" : "서클 삭제",
     "Contacts settings" : "연락처 설정",
     "General settings" : "일반 설정",
     "Update avatars from social media" : "소셜 네트워크에서 아바타 업데이트",
@@ -31,17 +26,13 @@ OC.L10N.register(
     "Address books" : "주소록",
     "Export" : "내보내기",
     "Send email" : "이메일 보내기",
+    "Send email as BCC" : "BCC로 이메일 보내기",
     "Contact groups" : "연락처 그룹",
     "Create a new contact group" : "새 연락처 그룹 생성",
     "Contact group name" : "연락처 그룹 이름",
-    "Circles" : "서클",
-    "Create a new circle" : "새 서클 만들기",
     "Show all groups" : "모든 그룹 보이기",
     "Collapse groups" : "그룹 접기",
-    "Show all circles" : "모든 서클 보이기",
-    "Collapse circles" : "서클 접기",
     "This group already exists" : "그룹이 이미 존재함",
-    "This circle already exists" : "서클이 이미 존재함",
     "{addressbookname} (Disabled)" : "{addressbookname} (비활성화됨)",
     "Download" : "다운로드",
     "Show" : "보이기",
@@ -80,20 +71,20 @@ OC.L10N.register(
     "Sort by {sorting}" : "{sorting}(으)로 정렬",
     "An error happened during the config change" : "변경 사항을 설정하는 중 오류 발생",
     "Password protection" : "암호 보호",
+    "Unique password …" : "독자 암호 ...",
     "Save" : "저장",
+    "Change unique password" : "독자 암호 변경",
     "Failed to save password. Please try again later." : "암호를 저장하는 데 실패했습니다. 잠시 후 다시 시도하십시오.",
-    "Circle name" : "서클 이름",
-    "Circle owned by {owner}" : "{owner}님이 소유한 서클",
     "Request to join" : "등록 요청",
     "Description" : "설명",
-    "There is no description for this circle" : "이 서클에는 설명이 없음",
-    "Enter a description for the circle" : "이 서클에 대한 설명 입력",
+    "Add members" : "회원 추가",
+    "Settings" : "Settings",
     "An error happened during description sync" : "설명 동기화 중 오류 발생",
     "An error happened during name sync" : "이름 동기화 중 오류 발생",
+    "Cancel" : "취소",
     "Add more info" : "정보 추가",
     "More fields" : "더 많은 입력란",
     "Crop contact photo" : "연락처 사진 잘라내기",
-    "Cancel" : "취소",
     "Upload a new picture" : "새 그림 업로드",
     "Choose from Files" : "파일에서 선택",
     "Get from " : "가져오기 - ",
@@ -119,6 +110,12 @@ OC.L10N.register(
     "Contact vCard as QR code" : "QR 코드로 된 vCard 연락처",
     "Pick an address book" : "주소록 선택",
     "Select address book" : "주소록 선택",
+    "Go to talk conversation" : "Talk 대화로 이동",
+    "View profile" : "프로필 보기",
+    "Media shares with you" : "나와 공유된 미디어",
+    "Talk conversations with you" : "나와의 Talk 대화",
+    "Calendar events with you" : "나와의 달력 일정",
+    "No shared items with this contact" : "이 연락처와 공유된 항목 없음",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "이 연락처는 읽기 전용 모드입니다. 편집할 수 있는 권한이 없습니다.",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "편집하려고 하는 연락처가 변경되었습니다. 연락처를 직접 새로 고치십시오. 추가 변경 사항은 손실됩니다.",
     "Address book" : "주소록",
@@ -139,20 +136,12 @@ OC.L10N.register(
     "No results" : "결과 없음",
     "Add to group" : "그룹에 추가",
     "Add {type}" : "{type} 추가",
-    "New circle name" : "새 서클 이름",
-    "Personal circle" : "개인 서클",
-    "This circle will only be visible to you. Other members will not be able to see or use it." : "이 서클은 당신에게만 보입니다. 다른 회원은 보거나 이용할 수 없습니다.",
-    "Local circle" : "로컬 서클",
-    "Create circle" : "서클 만들기",
     "Loading members list …" : "회원 목록 불러오는 중 ...",
     "You currently have no access to the member list" : "현재 이 구성원 목록에 접근할 수 없습니다",
-    "Add members" : "회원 추가",
-    "Show circle details" : "서클 자세히 보기",
     "Add to {circle}" : "{circle}에 추가",
     "Unable to get the recommendations list" : "추천 목록을 받아올 수 없음",
     "Unable to get the results" : "결과를 받아올 수 없음",
     "Some members could not be added" : "일부 회원을 추가할 수 없음",
-    "There was an issue adding members to the circle" : "서클에 회원을 추가하는 중 문제 발생",
     "Accept membership request" : "가입 요청 수락",
     "Reject membership request" : "가입 요청 거절",
     "Manage level" : "레벨 관리",
@@ -164,10 +153,12 @@ OC.L10N.register(
     "Could not delete the member {displayName}" : "{displayName} 회원을 삭제할 수 없습니다.",
     "Could not change the member level to {level}" : "회원 레벨을 {level}로 바꿀 수 없습니다.",
     "Could not accept membership request" : "가입 요쳥을 수락할 수 없습니다",
+    "Chart" : "차트",
+    "Select chart …" : "차트 선택 ...",
     "Select type" : "종류 선택",
     "Select Date" : "날짜 선택",
     "Add contact in group" : "그룹에 연락처 추가",
-    "none" : "없음",
+    "None" : "없음",
     "Select option" : "옵션 선택",
     "New contact" : "새 연락처",
     "Unable to create the contact." : "연락처를 만들 수 없습니다.",
@@ -181,19 +172,13 @@ OC.L10N.register(
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{addressbook}에 %n 연락처 가져오기 완료"],
     "Import" : "가져오기",
     "Could not copy" : "복사할 수 없음",
-    "Join circle" : "서클 가입",
     "You are about to leave {circle}.\nAre you sure?" : "{circle} 서클에서 정말 떠나시겠습니까?",
-    "Please confirm circle leave" : "서클 떠나기를 확인해주세요.",
-    "Could not leave the circle {displayName}" : "[displayName} 서클을 떠날 수 없습니다.",
-    "Unable to join the circle" : "서클에 등록할 수 없음",
     "You are about to delete {circle}.\nAre you sure?" : "{circle} 서클을 정말 삭제하시겠습니까?",
-    "Please confirm circle deletion" : "서클 삭제를 확인해주세요.",
-    "Unable to delete the circle" : "서클을 삭제할 수 없습니다.",
     "Link copied to the clipboard" : "링크가 클립보드에 복사됨",
     "Could not copy link to the clipboard." : "링크를 클립보드에 복사할 수 없음",
     "Not grouped" : "그룹되지 않음",
     "Recently contacted" : "최근 연락함",
-    "Circle" : "서클",
+    "Organization chart" : "조직도",
     "User" : "사용자",
     "Group" : "그룹",
     "Email" : "이메일",
@@ -209,8 +194,6 @@ OC.L10N.register(
     "Members can also invite" : "회원도 초대 가능",
     "Visibility" : "표시 여부",
     "Visible to everyone" : "모두에게 보이기",
-    "Circle membership" : "서클 회원",
-    "Prevent circle from being a member of another circle" : "이 서클이 다른 서클의 회원이 될 수 없음",
     "Users" : "사용자",
     "Email addresses" : "이메일 주소",
     "Detailed name" : "자세한 이름",
@@ -268,13 +251,10 @@ OC.L10N.register(
     "Gender" : "성별",
     "Female" : "여성",
     "Male" : "남성",
-    "None" : "없음",
     "Unknown" : "알 수 없음",
     "Time zone" : "시간대",
     "Spoken languages" : "사용 언어",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["연락처 {failed}개를 읽을 수 없음"],
-    "Unable to create circle {circleName}" : "{circleName} 서클을 만들 수 없음",
-    "Unable to delete circle {circleId}" : "{circleId} 서클을 삭제할 수 없음",
     "Unable to delete contact" : "연락처를 삭제할 수 없음"
 },
 "nplurals=1; plural=0;");
