@@ -7,9 +7,6 @@ OC.L10N.register(
     "Copy to full name" : "Бүтэн нэр хуулах",
     "Loading …" : "Уншиж байна...",
     "Add member" : "Гишүүн нэмэх",
-    "Delete circle" : "бүлгийг устгах",
-    "Circles" : "Тойрог",
-    "Create a new circle" : "шинэ бүлэг үүсгэх",
     "Download" : "Татаж авах",
     "Rename" : "Нэр солих",
     "Delete" : "Устгах",
@@ -25,6 +22,7 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Save" : "Хадгалах",
     "Description" : "Тайлбар",
+    "Settings" : "Settings",
     "Cancel" : "болиулах",
     "Upload a new picture" : "Шинэ зураг оруулах",
     "Choose from Files" : "Файлаас сонгох",
@@ -36,13 +34,12 @@ OC.L10N.register(
     "Select address book" : "Хаягийн бүртгэл сонгох",
     "Address book" : "Хаягийн бүртгэл",
     "No results" : "Үр дүн байхгүй",
-    "Personal circle" : "Хувийн тойрог",
     "Pending" : "Хүлээгдэж байгаа",
+    "None" : "юу ч үгүй",
     "New contact" : "Шинэ харилцагч",
     "Close" : "Хаах",
     "Import" : "Импорт",
     "Not grouped" : "Багт ороогүй",
-    "Circle" : "Тойрог",
     "User" : "Хэрэглэгч",
     "Group" : "Бүлэг",
     "Email" : "Цахим шуудан",
@@ -87,7 +84,6 @@ OC.L10N.register(
     "Gender" : "Хүйс",
     "Female" : "Эмэгтэй",
     "Male" : "Эрэгтэй",
-    "None" : "юу ч үгүй",
     "Unknown" : "Үл танигдах зүйл",
     "Time zone" : "Цагийн бүс"
 },
