@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Details" : "Detaljar",
     "Contacts" : "Kontaktar",
-    "Circles" : "Sirklar",
     "Download" : "Last ned",
     "Rename" : "Gje nytt namn",
     "Delete" : "Ta bort",
@@ -14,15 +13,16 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Save" : "Lagre",
     "Description" : "Skildring",
+    "Settings" : "nstillingar",
     "Cancel" : "Avbryt",
     "Invalid image" : "Ugyldig bilete",
     "Name" : "Namn",
     "Title" : "Tittel",
     "Pending" : "Under vegs",
+    "None" : "Ingen",
     "Close" : "Lukk",
     "Import" : "Importer",
     "Not grouped" : "Ikkje gruppert",
-    "Circle" : "Sirkel",
     "User" : "Bruker",
     "Group" : "Gruppe",
     "Email" : "E-post",
@@ -48,7 +48,6 @@ OC.L10N.register(
     "Fax" : "Faks",
     "Pager" : "Personsøkjar",
     "Voice" : "Tale",
-    "None" : "Ingen",
     "Unknown" : "Ukjend"
 },
 "nplurals=2; plural=(n != 1);");
