@@ -7,7 +7,6 @@ OC.L10N.register(
     "Loading …" : "Cargament…",
     "General settings" : "Paramètres generals",
     "Send email" : "Enviar email",
-    "Circles" : "Cercles",
     "Download" : "Telecargar",
     "Rename" : "Renomenar",
     "Delete" : "Suprimir",
@@ -19,6 +18,7 @@ OC.L10N.register(
     "Password protection" : "Proteccion per senhal",
     "Save" : "Enregistrar",
     "Description" : "Descripcion",
+    "Settings" : "Settings",
     "Cancel" : "Anullar",
     "Invalid image" : "Imatge invalid",
     "Name" : "Nom",
@@ -27,6 +27,7 @@ OC.L10N.register(
     "Search contacts …" : "Cercar pels contactes…",
     "No results" : "Cap de resultat",
     "Pending" : "En espèra",
+    "None" : "Pas cap",
     "New contact" : "Contacte novèl",
     "Close" : "Tampar",
     "Import" : "Importar",
@@ -63,7 +64,6 @@ OC.L10N.register(
     "Pager" : "Messatgièr",
     "Voice" : "Votz",
     "Relative" : "Relatiu",
-    "None" : "Pas cap",
     "Unknown" : "Desconegut",
     "Spoken languages" : "Lengas parladas"
 },
