@@ -6,10 +6,7 @@ OC.L10N.register(
     "Contacts" : "Contacte",
     "Loading contacts …" : "Se încarcă contactele ...",
     "Loading …" : "Se încarcă…",
-    "Delete circle" : "Șterge cerc",
     "Send email" : "Trimite email-ul",
-    "Circles" : "Cercuri",
-    "Create a new circle" : "Crează un cerc nou",
     "Download" : "Descărcare",
     "Rename" : "Redenumește",
     "Delete" : "Șterge",
@@ -24,6 +21,7 @@ OC.L10N.register(
     "Password protection" : "Protecție parolă ",
     "Save" : "Salvează",
     "Description" : "Descriere",
+    "Settings" : "Settings",
     "Cancel" : "Anulează",
     "Invalid image" : "Imagine invalidă",
     "Name" : "Nume",
@@ -32,15 +30,14 @@ OC.L10N.register(
     "Address book" : "Listă de contacte",
     "Search contacts …" : "Caută contacte ...",
     "No results" : "Niciun rezultat",
-    "Personal circle" : "Cerc personal",
     "Pending" : "În așteptare",
+    "None" : "Niciuna",
     "Select option" : "Selectatți opțiunea",
     "New contact" : "Contact nou ",
     "Close" : "Închide",
     "Import" : "Importă",
     "Not grouped" : "Negrupate",
     "Recently contacted" : "Contactat recent",
-    "Circle" : "Cerc",
     "User" : "Utilizator",
     "Group" : "Grup",
     "Email" : "Email",
@@ -99,7 +96,6 @@ OC.L10N.register(
     "Gender" : "Sex",
     "Female" : "Femeie",
     "Male" : "Bărbat",
-    "None" : "Niciuna",
     "Unknown" : "Necunoscut"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
