@@ -8,11 +8,8 @@ OC.L10N.register(
     "Copy to full name" : "Kopje të emrit të plotë ",
     "Omit year" : "Shmang vitin",
     "Loading contacts …" : "Duke ngarkuar kontaktet ...",
-    "Delete circle" : "Fshini rrethin",
     "General settings" : "Opsjonet e Pergjithshme",
     "Send email" : "Dërgo email",
-    "Circles" : "Rrethet",
-    "Create a new circle" : "Krijo një rreth të ri",
     "Download" : "Shkarko",
     "Rename" : "Riemëro",
     "Delete" : "Fshije",
@@ -49,16 +46,15 @@ OC.L10N.register(
     "Syntax error. Cannot open the contact." : "Gabim sintakse. Kontakti nuk mund të hapet.",
     "Search contacts …" : "Kërko kontakte ...",
     "No results" : "Asnjë rezultat",
-    "Personal circle" : "Rreth personal",
     "Pending" : "Në Pritje të Konfirmimit",
     "Select type" : "Zgjidhni llojin",
     "Select Date" : "Zgjidhni Datën",
     "Add contact in group" : "Shto kontaktin në grup",
+    "None" : "Asnjë",
     "New contact" : "Kontakt i ri",
     "Close" : "Mbylleni",
     "Import" : "Import",
     "Not grouped" : "I pagrupuar",
-    "Circle" : "Rreth",
     "User" : "Përdorues",
     "Group" : "Grup",
     "Email" : "Email",
@@ -117,7 +113,6 @@ OC.L10N.register(
     "Gender" : "Gjinia",
     "Female" : "Femër",
     "Male" : "Mashkull",
-    "None" : "Asnjë",
     "Unknown" : "I/E panjohur"
 },
 "nplurals=2; plural=(n != 1);");
