@@ -9,9 +9,6 @@ OC.L10N.register(
     "Copy to full name" : "复制到全名",
     "Omit year" : "忽略年份",
     "Allow updating avatars from social media" : "允许从社交媒体资料更新头像",
-    "Please select a circle" : "请选择一个圈子",
-    "Loading circle …" : "正在加载圈子 ...",
-    "Your request to join this circle is pending approval" : "您加入这个圈子的请求正在等待批准",
     "You are not a member of {circle}" : "您并非 {circle} 的成员",
     "There was an error fetching the member list" : "获取成员列表时发生一个错误",
     "Loading contacts …" : "正在加载联系人 ...",
@@ -22,8 +19,6 @@ OC.L10N.register(
     "Add contacts" : "添加联系人",
     "Loading …" : "正在加载…",
     "Add member" : "添加成员",
-    "Leave circle" : "离开圈子",
-    "Delete circle" : "删除圈子",
     "Contacts settings" : "联系人设置",
     "General settings" : "一般设置",
     "Update avatars from social media" : "从社交媒体更新头像",
@@ -35,15 +30,9 @@ OC.L10N.register(
     "Contact groups" : "联系人群组",
     "Create a new contact group" : "创建联系人群组",
     "Contact group name" : "联系人群组名称",
-    "Circles" : "圈子",
-    "Create a new circle" : "新建一个圈子",
     "Show all groups" : "显示所有小组",
     "Collapse groups" : "折叠小组",
-    "Show all circles" : "显示所有圈子",
-    "Collapse circles" : "折叠圈子",
     "This group already exists" : "该群组已存在",
-    "This circle already exists" : "这个圈子已经存在",
-    "An error happened during the creation of the circle" : "创建圈子时发生一个错误",
     "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
     "Download" : "下载",
     "Show" : "显示",
@@ -85,24 +74,21 @@ OC.L10N.register(
     "Oversees" : "监督",
     "An error happened during the config change" : "更改配置时发生一个错误",
     "Password protection" : "密码保护",
-    "Enforce password protection on files shared to this circle" : "对分享到该圈子中的文件强制使用密码保护",
-    "Use a unique password for all shares to this circle" : "对分享到该圈子中的文件使用独立密码",
     "Unique password …" : "独立密码 ...",
     "Save" : "保存",
     "Change unique password" : "修改独立密码",
     "Failed to save password. Please try again later." : "保存密码失败，请稍后重试。",
-    "Circle name" : "圈子名称",
-    "Circle owned by {owner}" : "圈子所有者为  {owner}",
     "Request to join" : "请求加入",
     "Description" : "描述",
-    "There is no description for this circle" : "这个圈子没有描述",
-    "Enter a description for the circle" : "为这个圈子输入一个描述",
+    "Add members" : "添加成员",
+    "Settings" : "Settings",
     "An error happened during description sync" : "描述同步期间发生一个错误",
     "An error happened during name sync" : "名称同步期间发生了一个错误",
+    "Cancel" : "取消",
+    "Confirm" : "确认",
     "Add more info" : "添加更多信息",
     "More fields" : "更多领域",
     "Crop contact photo" : "裁剪联系人照片",
-    "Cancel" : "取消",
     "Upload a new picture" : "上传一张新的图片",
     "Choose from Files" : "从文件中选择",
     "Get from " : "获取自",
@@ -130,6 +116,11 @@ OC.L10N.register(
     "Select address book" : "选择地址簿",
     "Go to talk conversation" : "前往对话",
     "View profile" : "查看个人资料",
+    "Media shares with you" : "与您分享的媒体",
+    "Talk conversations with you" : "与您展开的对话",
+    "Calendar events with you" : "与您分享的日历事件",
+    "Deck cards with you" : "与您分享的卡片",
+    "No shared items with this contact" : "与该联系人无共享项目",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此联系人处于只读模式。 您无权编辑此联系人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您尝试编辑的联系人已更改。 请手动刷新联系人。 任何进一步的编辑都不会被保存。",
     "Address book" : "地址簿",
@@ -150,22 +141,12 @@ OC.L10N.register(
     "No results" : "无结果",
     "Add to group" : "添加到群组",
     "Add {type}" : "添加  {type}",
-    "New circle name" : "新的圈子名称",
-    "Personal circle" : "个人圈子",
-    "This circle will only be visible to you. Other members will not be able to see or use it." : "这个圈子仅对您可见，其他成员无法看见或使用它。",
-    "Local circle" : "本地圈子",
-    "This circle will not be shared with the other instances of the global scale" : "这个圈子不会与全球范围内的其他实例共享 ",
-    "Create circle" : "创建圈子",
     "Loading members list …" : "正在加载成员列表 ...",
-    "The list of members is only visible to members of this circle" : "成员列表仅对这个圈子的成员可见",
     "You currently have no access to the member list" : "您目前无法访问成员列表",
-    "Add members" : "添加成员",
-    "Show circle details" : "显示圈子详情",
     "Add to {circle}" : "添加到 {circle}",
     "Unable to get the recommendations list" : "无法获取推荐列表",
     "Unable to get the results" : "无法获得结果",
     "Some members could not be added" : "无法添加一些成员",
-    "There was an issue adding members to the circle" : "添加成员到这个圈子时出错",
     "Accept membership request" : "接受成员身份请求",
     "Reject membership request" : "拒绝成员身份请求",
     "Manage level" : "管理级别",
@@ -182,7 +163,7 @@ OC.L10N.register(
     "Select type" : "选择类型",
     "Select Date" : "选择日期",
     "Add contact in group" : "添加联系人到群组",
-    "none" : "无",
+    "None" : "无",
     "Select option" : "选择选项",
     "Add property of this type" : "为此类型添加属性",
     "New contact" : "新建联系人",
@@ -196,22 +177,15 @@ OC.L10N.register(
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在导入 %n 个联系人到 {addressbook}"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["已将 %n 个联系人导入到 {addressbook}"],
     "Import" : "导入",
+    "Are you sure you want to import this contact file?" : "您确定您想要导入此联系人文件吗？",
     "Could not copy" : "无法复制",
-    "Join circle" : "加入圈子",
     "You are about to leave {circle}.\nAre you sure?" : "您即将离开 {circle}\n确定吗？",
-    "Please confirm circle leave" : "请确认离开此圈子",
-    "Could not leave the circle {displayName}" : "无法离开圈子 {displayName}",
-    "Unable to join the circle" : "无法加入这个圈子",
     "You are about to delete {circle}.\nAre you sure?" : "您即将删除 {circle}\n确定吗？",
-    "Please confirm circle deletion" : "请确认删除操作",
-    "Unable to delete the circle" : "无法删除圈子",
     "Link copied to the clipboard" : "链接已复制到剪贴板",
     "Could not copy link to the clipboard." : "无法复制链接到剪贴板",
     "Not grouped" : "未分组",
     "Recently contacted" : "最近联系",
     "Organization chart" : "组织图",
-    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "小圈圈是您可以自行建立并与他们分享资料的一群人。其可以由 Nextcloud 实例的其他账号或账号群组所组成，但也可以由您通讯录中的联络人组成，甚至可以通过输入邮件地址来添加外部人员。",
-    "Circle" : "圈子",
     "User" : "用户",
     "Group" : "小组",
     "Email" : "电子邮件",
@@ -227,8 +201,6 @@ OC.L10N.register(
     "Members can also invite" : "成员也可以邀请",
     "Visibility" : "可见性",
     "Visible to everyone" : "对所有人可见",
-    "Circle membership" : "圈子成员资格",
-    "Prevent circle from being a member of another circle" : "防止圈子成为另一个圈子的成员",
     "Users" : "用户",
     "Email addresses" : "电子邮件地址",
     "Detailed name" : "全名",
@@ -286,14 +258,10 @@ OC.L10N.register(
     "Gender" : "性别",
     "Female" : "女性",
     "Male" : "男性",
-    "None" : "无",
     "Unknown" : "未知",
     "Time zone" : "时区",
     "Spoken languages" : "口语",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 个联系人读取失败"],
-    "An error has occurred in circle(s). Check the console for more details." : "圈子中出现错误。请查看控制台以获取详细信息。",
-    "Unable to create circle {circleName}" : "无法创建圈子 {circleName}",
-    "Unable to delete circle {circleId}" : "无法删除圈子 {circleId}",
     "Unable to delete contact" : "无法删除联系人"
 },
 "nplurals=1; plural=0;");
