@@ -9,9 +9,9 @@ OC.L10N.register(
     "Copy to full name" : "複製到全名",
     "Omit year" : "省略年份",
     "Allow updating avatars from social media" : "允許從社群媒體更新虛擬化身大頭照",
-    "Please select a circle" : "請選擇社交圈子",
-    "Loading circle …" : "社交圈子加載中 ...",
-    "Your request to join this circle is pending approval" : "您加入此圈子的請求正在等待批准",
+    "Please select a team" : "請選取團隊",
+    "Loading team…" : "正在加載團隊 …",
+    "Your request to join this team is pending approval" : "您加入此團隊的請求正在等待批准",
     "You are not a member of {circle}" : "您不是 {circle} 的成員",
     "There was an error fetching the member list" : "擷取成員清單出錯",
     "Loading contacts …" : "正在載入通訊錄 …",
@@ -22,8 +22,8 @@ OC.L10N.register(
     "Add contacts" : "新增聯絡人",
     "Loading …" : "正在載入 …",
     "Add member" : "添加成員",
-    "Leave circle" : "離開社交圈子",
-    "Delete circle" : "刪除社交圈子",
+    "Leave team" : "離開團隊",
+    "Delete team" : "刪除團隊",
     "Contacts settings" : " 通訊錄設定",
     "General settings" : "一般設定",
     "Update avatars from social media" : "從社群媒體更新虛擬化身大頭照",
@@ -35,15 +35,15 @@ OC.L10N.register(
     "Contact groups" : "聯絡群組",
     "Create a new contact group" : "創建新聯絡人群組",
     "Contact group name" : "聯絡人群組名稱",
-    "Circles" : "社交圈子",
-    "Create a new circle" : "創建新社交圈子",
+    "Teams" : "團隊",
+    "Create a new team" : "創建新團隊",
     "Show all groups" : "顯示所有群組",
     "Collapse groups" : "收合群組",
-    "Show all circles" : "顯示所有社交圈子",
-    "Collapse circles" : "收合社交圈子",
+    "Show all teams" : "顯示所有團隊",
+    "Collapse teams" : "折疊團隊",
     "This group already exists" : "該群組已存在",
-    "This circle already exists" : "此社交圈子已存在",
-    "An error happened during the creation of the circle" : "創建社交圈子的過程中發生錯誤",
+    "This team already exists" : "此團隊已存在",
+    "An error happened during the creation of the team" : "建立團隊時發生錯誤",
     "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
     "Download" : "下載",
     "Show" : "顯示",
@@ -85,24 +85,33 @@ OC.L10N.register(
     "Oversees" : "監督",
     "An error happened during the config change" : "配置更改期間發生錯誤",
     "Password protection" : "密碼保護",
-    "Enforce password protection on files shared to this circle" : "對分享到此圈子的檔案實施密碼保護",
-    "Use a unique password for all shares to this circle" : "對此圈子的所有分享使用獨一無二的密碼",
+    "Enforce password protection on files shared to this team" : "對分享到此團隊的檔案加上密碼保護",
+    "Use a unique password for all shares to this team" : "對此團隊的所有分享使用獨一無二的密碼",
     "Unique password …" : "獨一無二的密碼 ...",
     "Save" : "保存",
     "Change unique password" : "更改獨一無二的密碼",
     "Failed to save password. Please try again later." : "保存密碼失敗。請稍後再試。",
-    "Circle name" : "社交圈子名稱",
-    "Circle owned by {owner}" : "{owner} 擁有的社交圈子",
+    "Team owned by {owner}" : "{owner} 擁有的團隊",
+    "Team settings" : "團隊設定",
     "Request to join" : "請求加入",
     "Description" : "描述",
-    "There is no description for this circle" : "此社交圈子沒有任何描述",
-    "Enter a description for the circle" : "輸入社交圈子的描述",
+    "Members" : "成員",
+    "Add members" : "添加成員",
+    "Team members" : "團隊成員",
+    "Team resources" : "團隊資源",
+    "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
+    "Team name" : "團隊名字",
+    "Settings" : "Settings",
+    "Actions" : "操作",
+    "There is no description for this team" : "此團隊沒有描述",
+    "Enter a description for the team" : "輸入團隊的描述",
     "An error happened during description sync" : "描述同步期間發生錯誤",
     "An error happened during name sync" : "名稱同步期間發生錯誤",
+    "Cancel" : "取消",
+    "Confirm" : "確認",
     "Add more info" : "添加更多資料",
     "More fields" : "更多欄位",
     "Crop contact photo" : "裁剪聯絡人照片",
-    "Cancel" : "取消",
     "Upload a new picture" : "上傳一張新的圖片",
     "Choose from Files" : "從檔案選取",
     "Get from " : "取自",
@@ -130,6 +139,11 @@ OC.L10N.register(
     "Select address book" : "選擇通訊錄",
     "Go to talk conversation" : "前往對話",
     "View profile" : "檢視個人檔案",
+    "Media shares with you" : "與您分享的媒體",
+    "Talk conversations with you" : "與您的 Talk 對話",
+    "Calendar events with you" : "與您分享的日曆活動",
+    "Deck cards with you" : "與您分享的 Deck 卡片",
+    "No shared items with this contact" : "沒有與該聯絡人分享的項目",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
     "Address book" : "通訊錄",
@@ -150,22 +164,21 @@ OC.L10N.register(
     "No results" : "沒有結果",
     "Add to group" : "新增至群組",
     "Add {type}" : "新增 {type}",
-    "New circle name" : "新社交圈子名稱",
-    "Personal circle" : "個人社交圈子",
-    "This circle will only be visible to you. Other members will not be able to see or use it." : "這個圈子只有你能看到。其他成員將無法看到或使用它。",
-    "Local circle" : "近端社交圈子",
-    "This circle will not be shared with the other instances of the global scale" : "此社交圈子不會與全球範圍內的其他實例共享",
-    "Create circle" : "創建社交圈子",
+    "New team name" : "新團隊名字",
+    "Personal team" : "個人團隊",
+    "This team will only be visible to you. Other members will not be able to see or use it." : "此團隊僅有您可見。其他成員將無法看到或使用它。",
+    "Local team" : "本地團隊",
+    "This team will not be shared with the other instances of the global scale" : "此團隊不會與全球範圍內的其他實例共享",
+    "Create team" : "創建團隊",
     "Loading members list …" : "正在加載成員清單 …",
-    "The list of members is only visible to members of this circle" : "成員列表僅此圈子的成員可見",
+    "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
     "You currently have no access to the member list" : "您目前無權存取會員清單",
-    "Add members" : "添加成員",
-    "Show circle details" : "顯示社交圈子細節",
+    "Show team details" : "顯示團隊詳細資訊",
     "Add to {circle}" : "添加到 {circle}",
     "Unable to get the recommendations list" : "無法獲取推薦列表",
     "Unable to get the results" : "無法得到結果",
     "Some members could not be added" : "部分成員無法添加",
-    "There was an issue adding members to the circle" : "將成員添加到社交圈子時出現問題",
+    "There was an issue adding members to the team" : "將成員添加到團隊時出現問題",
     "Accept membership request" : "接受會員申請",
     "Reject membership request" : "拒絕會員申請",
     "Manage level" : "管理程度",
@@ -182,7 +195,7 @@ OC.L10N.register(
     "Select type" : "選擇類型",
     "Select Date" : "選擇日期",
     "Add contact in group" : "新增聯絡人到群組",
-    "none" : "無",
+    "None" : "無",
     "Select option" : "選擇選項",
     "Add property of this type" : "添加此類型的屬性",
     "New contact" : "新聯絡人",
@@ -196,22 +209,23 @@ OC.L10N.register(
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在導入 %n 個聯絡人至 {addressbook}"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["完成導入 %n 個聯絡人至 {addressbook}"],
     "Import" : "導入",
+    "Are you sure you want to import this contact file?" : "您確定您想要匯入此聯絡人檔案嗎？",
     "Could not copy" : "無法複製",
-    "Join circle" : "加入社交圈子",
+    "Join team" : "加入團隊",
     "You are about to leave {circle}.\nAre you sure?" : "您即將離開 {circle}。\n你確定嗎？",
-    "Please confirm circle leave" : "請確認您要離開此社交圈子",
-    "Could not leave the circle {displayName}" : "不能退出社交圈子 {displayName}",
-    "Unable to join the circle" : "無法加入社交圈子",
+    "Please confirm team leave" : "請確認您要離開團隊",
+    "Could not leave the team {displayName}" : "無法離開團隊 {displayName}",
+    "Unable to join the team" : "無法加入團隊",
     "You are about to delete {circle}.\nAre you sure?" : "您即將刪除 {circle}。\n你確定嗎？",
-    "Please confirm circle deletion" : "請確認社交圈子刪除",
-    "Unable to delete the circle" : "無法刪除社交圈子",
+    "Please confirm team deletion" : "請確認您要刪除團隊",
+    "Unable to delete the team" : "無法刪除這個團隊",
     "Link copied to the clipboard" : "已複製連結至剪貼板",
     "Could not copy link to the clipboard." : "無法複製連結至剪貼板",
     "Not grouped" : "未歸類",
     "Recently contacted" : "最近聯絡",
     "Organization chart" : "機構圖表",
-    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "小圈圈是您可以自行建立並與他們分享資料的一群人。其可以由 Nextcloud 站台的其他帳號或帳號群組所組成，但也可以由您通訊錄中的聯絡人組成，甚至可以透過輸入電子郵件地址來組成外部人員。",
-    "Circle" : "社交圈子",
+    "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "團隊是您可以自行建立並與他們分享資料的一群人。其可以由 Nextcloud 站台的其他帳號或帳號群組所組成，但也可以由您通訊錄中的聯絡人組成，甚至可以透過輸入電子郵件地址來組成外部人員。",
+    "Team" : "團隊",
     "User" : "用戶",
     "Group" : "群組",
     "Email" : "電郵地址",
@@ -227,8 +241,8 @@ OC.L10N.register(
     "Members can also invite" : "會員也可以邀請",
     "Visibility" : "可見性",
     "Visible to everyone" : "所有人都看得到",
-    "Circle membership" : "社交圈子會員",
-    "Prevent circle from being a member of another circle" : "防止社交圈子成為另一個圈子的成員",
+    "Team membership" : "團隊成員身分",
+    "Prevent teams from being a member of another team" : "防止團隊成為另一個團隊的成員",
     "Users" : "用戶",
     "Email addresses" : "電郵地址",
     "Detailed name" : "詳細名稱",
@@ -286,14 +300,13 @@ OC.L10N.register(
     "Gender" : "性別",
     "Female" : "女性",
     "Male" : "男性",
-    "None" : "無",
     "Unknown" : "不詳",
     "Time zone" : "時區",
     "Spoken languages" : "會說的語言",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 個聯絡人讀取失敗"],
-    "An error has occurred in circle(s). Check the console for more details." : "圈子中出現錯誤。 請查看控制台以獲取更多詳細資訊。",
-    "Unable to create circle {circleName}" : "無法創建社交圈子 {circleName}",
-    "Unable to delete circle {circleId}" : "無法刪除社交圈子 {circleId}",
+    "An error has occurred in team(s). Check the console for more details." : "團隊中出現錯誤。請檢查主控台以取得更多詳細資訊。",
+    "Unable to create team {circleName}" : "無法建立團隊 {circleName}",
+    "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
     "Unable to delete contact" : "無法刪除聯絡人"
 },
 "nplurals=1; plural=0;");
